<?php
include 'dbfunc.php';

class func
{
	static function getCpuClock() {
		if(file_exists('/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq')) {			
			$file  = trim(file_get_contents('/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq'));
			return floatval(substr($file, 0, -3) .'.'. substr($file, -3));			
		} 		
		$file = file_get_contents('/proc/cpuinfo');
		preg_match('#BogoMIPS\s*:\s*(\d*\.\d*)#i', $file, $match);
		return floatval($match[1]);		
	}
	
	static function getHostname() {		
		$host = trim(file_get_contents('/proc/sys/kernel/hostname'));
		return $host;		
	}
	
	static  function getHostAddr() {		
		if(!isset($_SERVER['SERVER_ADDR'])) {			
			return 'unknown';			
		}		
		if(!$ip = $_SERVER['SERVER_ADDR']) {			
			return gethostbyname($this->getHostname());			
		}		
		return $ip;		
	}
	
	static function getSysLoad() {
		
		return sys_getloadavg();
		
	}
	
	static function getMemoryUsage() {
		
		exec('free -bo', $data);
		list($type, $total, $used, $free, $shared, $buffers, $cached) = preg_split('#\s+#', $data[1]);
		$usage = round(($used - $buffers - $cached) / $total * 100);
		
		return array('percent' => $usage, 'total' => round($total/1000), 'free' => round(($free + $buffers + $cached)/1000) , 'used' => round(($used - $buffers - $cached)/1000));
	}
	
	static function getCoreTemprature(){
		$file = @file_get_contents('/sys/class/thermal/thermal_zone0/temp');
		if($file != false) {			
			return round(substr(trim($file), 0, 2) .'.'. substr(trim($file), 2), 2);
		}		
		return 0.0;
	}
	
	static function getRpiSerial() {		
		$file = file_get_contents('/proc/cpuinfo');
		preg_match('#Serial\s*:\s*([\da-f]+)#i', $file, $match);
		
		if(isset($match[1])) {			
			return $match[1];		
		}
		return null;
	}
	
	static function getUptime() {		
		$file = file_get_contents('/proc/uptime');
		$time = preg_split('#\s+#', trim($file));
		return round($time[0], 0);		
	}
	
	static function getLastBootTime() {		
		return TIME_NOW - $this->getUptime();
	}
	
	static function formatTimefromSeconds($seconds, $short = false) {
	
		if($seconds < 0) {
			$seconds = $seconds * -1;
		}
		
		$jears   = 0;
		$month   = 0;
		$weeks   = 0;
		$days    = 0;
		$hours   = 0;
		$minutes = 0;
		$sec     = 0;
		 
		//Jahre
		$jears_in_sec = 365 * 24 * 60 * 60;
		if($seconds >= $jears_in_sec) {
			$jears = floor($seconds / $jears_in_sec);
			$seconds -= $jears * $jears_in_sec;
		}
		//Monate
		$month_in_sec = 30 * 24 * 60 * 60;
		if($seconds >= $month_in_sec) {
			$month = floor($seconds / $month_in_sec);
			$seconds -= $month * $month_in_sec;
		}
		//Wochen
		$weeks_in_sec = 7 * 24 * 60 * 60;
		if($seconds >= $weeks_in_sec) {
			$weeks = floor($seconds / $weeks_in_sec);
			$seconds -= $weeks * $weeks_in_sec;
		}
		//Tage
		$days_in_sec = 24 * 60 * 60;
		if($seconds >= $days_in_sec) {
			$days = floor($seconds / $days_in_sec);
			$seconds -= $days * $days_in_sec;
		}
		//Stunden
		if($seconds >= 3600) {
			$hours = floor($seconds / 3600);
			$seconds -= $hours * 3600;
		}
		//Minuten
		if($seconds >= 60) {
			$minutes = floor($seconds / 60);
			$seconds -= $minutes * 60;
		}
		//Sekunden
		$sec = $seconds;
	
		$first = false;
		$string = '';
	
		//Jahre
		if($jears > 0 || $first == true) {
			if($short == true) {
				$string .= $jears .' J, ';
			} else {
				$string .= $jears .' '. ($jears == 1 ? 'Jahr' : 'Jahre') .', ';
			}
			$first = true;
		}
		//Monate
		if($month > 0 || $first == true) {
			if($short == true) {
				$string .= $month .' M, ';
			} else {
				$string .= $month .' '. ($month == 1 ? 'Monat' : 'Monate') .', ';
			}
			$first = true;
		}
		//Wochen
		if($weeks > 0 || $first == true) {
			if($short == true) {
				$string .= $weeks .' W, ';
			} else {
				$string .= $weeks .' '. ($weeks == 1 ? 'Woche' : 'Wochen') .', ';
			}
			$first = true;
		}
		//Tage
		if($days > 0 || $first == true) {
			if($short == true) {
				$string .= $days .' D, ';
			} else {
				$string .= $days .' '. ($days == 1 ? 'Tag' : 'Tage') .', ';
			}
			$first = true;
		}
		//Stunden
		if($hours > 0 || $first == true) {
			if($short == true) {
				$string .= $hours .' S, ';
			} else {
				$string .= $hours .' '. ($hours == 1 ? 'Stunde' : 'Stunden') .', ';
			}
			$first = true;
		}
		//Minuten
		if($minutes > 0 || $first == true) {
			if($short == true) {
				$string .= $minutes .' min'.' min, ';
			} else {
				$string .= $minutes .' '. ($minutes == 1 ? 'Minute' : 'Minuten') .', ';
			}
			$first = true;
		}
		//Sekunden
		if($short == true) {
			$string .= $sec .' s';
		} else {
			$string .= $sec .' '. ($sec == 1 ? 'Sekunde' : 'Sekunden');
		}
		return trim($string);
	}
	
	static function showLoginFailed()
	{
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="400"><b><font size=5 color="FF0000">Failed to login!</font></b></td>';
		echo '</tr>';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="400"><a href=http://'.$host.$uri.'/index.php><img src="images/login.png" /></a></td>';
		echo '</tr>';
		echo '</table>';
		
		echo '</body>';
		echo '</html>';
	}
	
	static function showHeader($headerText)
	{
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<!DOCTYPE html>';
		echo '<html>';
		echo ' <meta name="viewport" content="width=400">'; 
		echo ' <head>';
		echo '  <title>HomeAuto - '.$headerText.'</title>';
		echo '  <style type="text/css">';
		echo '   .fehler { color: red; }';
		echo '  </style>';
		echo ' </head>';
		echo '<body>';
		
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td width="400" align="center"><a href=http://'.$host.$uri.'/main.php><img src="images/titel.jpg" width="300" height="45" alt="Simon Grimm" /></td>';
		echo '</tr>';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle"><b><font size=5>'.$headerText.'</font></b></td>';
		echo '</table>';
	}
	
	static function showMain()
	{
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<br>';
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="400"><a href=http://'.$host.$uri.'/main.php><img src="images/home.png" /></a></td>';
		echo '</table>';
		
		echo '</body>';
		echo '</html>';
	}
	
	static function showBack($backToPage, $parameter)
	{
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<br>';
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="400"><a href=http://'.$host.$uri.'/'.$backToPage.$parameter.'><img src="images/back.png" /></a></td>';
		echo '</table>';
		
		echo '</body>';
		echo '</html>';
	}
	
	static function showBackMain()
	{
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<br>';
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="400"><a href=http://'.$host.$uri.'/main.php><img src="images/home.png" /></a></td>';
		echo '</table>';
		
		echo '</body>';
		echo '</html>';
	}
	
	static function showBackRefresh($id)
	{	
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="200"><a href="http://'.$host.$uri.'/main.php"><img src="images/home.png" /></a></td>';
		echo '<td height="50" align="center" valign="middle" width="200"><a href="http://'.$host.$uri.'/device_showinfo.php?id='.$id.'"><img src="images/back.png" /></a></td>';
		echo '</tr>';
		echo '</table>';
		
		echo '</body>';
		echo '</html>';
	}
	
	static function showInfo($text)
	{	
		$host  = htmlspecialchars($_SERVER["HTTP_HOST"]);
		$uri   = rtrim(dirname(htmlspecialchars($_SERVER["PHP_SELF"])), "/\\");
		
		echo '<table border="0" cellpadding="0" cellspacing="0">';
		echo '<tr>';
		echo '<td height="50" align="center" valign="middle" width="400"><b><font color="FF0000">'.$text.'</font></b></td>';
		echo '</tr>';	
		echo '</table>';
		
		echo '</body>';
		echo '</html>';
	}
}
?>